@@ -57,4 +57,4 @@ class FlowerCommand(Command):
     def flower_option(arg):
         name, _, value = arg.lstrip('-').partition("=")
         name = name.replace('-', '_')
-        return name in options
+        return hasattr(options, name)
