@@ -24,13 +24,14 @@ class WorkersModel(BaseModel):
         for workername, stat in sorted(state.stats.iteritems()):
             pool = stat.get('pool') or {}
             self.workers[workername] = dict(
-                    status=(workername in state.ping),
-                    concurrency=pool.get('max-concurrency'),
-                    completed_tasks=sum(stat['total'].itervalues()),
-                    running_tasks=state.active_tasks.get(workername, []),
-                    queues=map(lambda x: x['name'],
-                               state.active_queues.get(workername, [])),
-                    )
+                status=(workername in state.ping),
+                concurrency=pool.get('max-concurrency'),
+                completed_tasks=sum(stat['total'].itervalues()),
+                running_tasks=len(state.active_tasks.get(workername, [])),
+                queues=map(lambda x: x['name'],
+                           state.active_queues.get(
+                           workername, [])),
+            )
 
     @classmethod
     def get_latest(cls, app):
@@ -72,13 +73,13 @@ class WorkerModel(BaseModel):
 
     def __eq__(self, other):
         return self.name == other.name and self.stats == other.stats and\
-               self.active_tasks == other.active_tasks and\
-               self.active_queues == other.active_queues and\
-               self.revoked_tasks == other.revoked_tasks and\
-               self.registered_tasks == other.registered_tasks and\
-               self.scheduled_tasks == other.scheduled_tasks and\
-               self.reserved_tasks == other.reserved_tasks and\
-               self.conf == other.conf
+            self.active_tasks == other.active_tasks and\
+            self.active_queues == other.active_queues and\
+            self.revoked_tasks == other.revoked_tasks and\
+            self.registered_tasks == other.registered_tasks and\
+            self.scheduled_tasks == other.scheduled_tasks and\
+            self.reserved_tasks == other.reserved_tasks and\
+            self.conf == other.conf
 
 
 class TaskModel(BaseModel):
@@ -102,8 +103,7 @@ class TaskModel(BaseModel):
     def iter_tasks(cls, app, limit=None, type=None, worker=None, state=None):
         i = 0
         events_state = app.events.state
-        for uuid, task in events_state._sort_tasks_by_time(
-                events_state.itertasks()):
+        for uuid, task in events_state.tasks_by_timestamp():
             if type and task.name != type:
                 continue
             if worker and task.worker.hostname != worker:
