@@ -50,7 +50,7 @@ var flower = (function () {
 
             $.ajax({
                 type: 'POST',
-                url: '/api/worker/shutdown/' + worker_name,
+                url: url_prefix() + '/api/worker/shutdown/' + worker_name,
                 dataType: 'json',
                 data: { workername: worker_name },
                 success: function (data) {
@@ -73,7 +73,7 @@ var flower = (function () {
 
             $.ajax({
                 type: 'POST',
-                url: '/api/worker/pool/restart/' + worker_name,
+                url: url_prefix() + '/api/worker/pool/restart/' + worker_name,
                 dataType: 'json',
                 data: { workername: worker_name },
                 success: function (data) {
@@ -95,7 +95,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/worker/pool/grow/' + workername,
+            url: url_prefix() + '/api/worker/pool/grow/' + workername,
             dataType: 'json',
             data: {
                 'workername': workername,
@@ -119,7 +119,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/worker/pool/shrink/' + workername,
+            url: url_prefix() + '/api/worker/pool/shrink/' + workername,
             dataType: 'json',
             data: {
                 'workername': workername,
@@ -144,7 +144,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/worker/pool/autoscale/' + workername,
+            url: url_prefix() + '/api/worker/pool/autoscale/' + workername,
             dataType: 'json',
             data: {
                 'workername': workername,
@@ -169,7 +169,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/worker/queue/add-consumer/' + workername,
+            url: url_prefix() + '/api/worker/queue/add-consumer/' + workername,
             dataType: 'json',
             data: {
                 'workername': workername,
@@ -178,7 +178,7 @@ var flower = (function () {
             success: function (data) {
                 show_success_alert(data.message);
                 setTimeout(function () {
-                    $('#tab-queues').load('/worker/' + workername + ' #tab-queues').fadeIn('show');
+                    $('#tab-queues').load(url_prefix() + '/worker/' + workername + ' #tab-queues').fadeIn('show');
                 }, 10000);
             },
             error: function (data) {
@@ -196,7 +196,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/worker/queue/cancel-consumer/' + workername,
+            url: url_prefix() + '/api/worker/queue/cancel-consumer/' + workername,
             dataType: 'json',
             data: {
                 'workername': workername,
@@ -205,7 +205,7 @@ var flower = (function () {
             success: function (data) {
                 show_success_alert(data.message);
                 setTimeout(function () {
-                    $('#tab-queues').load('/worker/' + workername + ' #tab-queues').fadeIn('show');
+                    $('#tab-queues').load(url_prefix() + '/worker/' + workername + ' #tab-queues').fadeIn('show');
                 }, 10000);
             },
             error: function (data) {
@@ -227,7 +227,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/task/timeout/' + workername,
+            url: url_prefix() + '/api/task/timeout/' + workername,
             dataType: 'json',
             data: {
                 'taskname': taskname,
@@ -254,7 +254,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/task/rate-limit/' + workername,
+            url: url_prefix() + '/api/task/rate-limit/' + workername,
             dataType: 'json',
             data: {
                 'taskname': taskname,
@@ -263,7 +263,7 @@ var flower = (function () {
             success: function (data) {
                 show_success_alert(data.message);
                 setTimeout(function () {
-                    $('#tab-limits').load('/worker/' + workername + ' #tab-limits').fadeIn('show');
+                    $('#tab-limits').load(url_prefix() + '/worker/' + workername + ' #tab-limits').fadeIn('show');
                 }, 10000);
             },
             error: function (data) {
@@ -280,7 +280,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/task/revoke/' + taskid,
+            url: url_prefix() + '/api/task/revoke/' + taskid,
             dataType: 'json',
             data: {
                 'terminate': false,
@@ -302,7 +302,7 @@ var flower = (function () {
 
         $.ajax({
             type: 'POST',
-            url: '/api/task/revoke/' + taskid,
+            url: url_prefix() + '/api/task/revoke/' + taskid,
             dataType: 'json',
             data: {
                 'terminate': true,
@@ -318,13 +318,14 @@ var flower = (function () {
 
     function on_workers_table_update(update) {
         $.each(update, function (name) {
-            var id = name.replace(/(:|\.)/g, '\\$1'),
-                tr = $('#' + id);
+            var id = encodeURIComponent(name),
+                sel = id.replace(/([ #;&,.+*~\':"!^$[\]()=>|\/%@])/g,'\\$1'),
+                tr = $('#' + sel);
 
             if (tr.length === 0) {
-                $('#workers-table-row').clone().removeClass('hidden').attr('id', name).appendTo('tbody');
-                tr = $('#' + id);
-                tr.children('td').children('a').attr('href', '/worker/' + id).text(name);
+                $('#workers-table-row').clone().removeClass('hidden').attr('id', id).appendTo('tbody');
+                tr = $('#' + sel);
+                tr.children('td').children('a').attr('href', url_prefix() + '/worker/' + name).text(name);
             }
 
             var stat = tr.children('td:eq(2)').children(),
@@ -446,10 +447,18 @@ var flower = (function () {
         return new Date().getTime() / 1000;
     }
 
+    function url_prefix() {
+        // prefix is initialized in base.html
+        if (prefix) {
+            return '/' + prefix;
+        }
+        return '';
+    }
+
     $(document).ready(function () {
-        if ($.inArray($(location).attr('pathname'), ['', '/workers'])) {
+        if ($.inArray($(location).attr('pathname'), [url_prefix(), url_prefix() + '/workers'])) {
             var host = $(location).attr('host'),
-                ws = new WebSocket("ws://" + host + "/update-workers");
+                ws = new WebSocket("ws://" + host + url_prefix() + "/update-workers");
             ws.onmessage = function (event) {
                 var update = $.parseJSON(event.data);
                 on_workers_table_update(update);
@@ -467,7 +476,7 @@ var flower = (function () {
             });
         });
 
-        if ($(location).attr('pathname') === '/monitor') {
+        if ($(location).attr('pathname') === url_prefix() + '/monitor') {
             var sts = current_unix_time(),
                 fts = current_unix_time(),
                 updateinterval = 3000,
@@ -476,7 +485,7 @@ var flower = (function () {
 
             $.ajax({
                 type: 'GET',
-                url: '/monitor/succeeded-tasks',
+                url: url_prefix() + '/monitor/succeeded-tasks',
                 data: {lastquery: current_unix_time()},
                 success: function (data) {
                     succeeded_graph = create_graph(data, '-succeeded');
@@ -485,7 +494,7 @@ var flower = (function () {
                     succeeded_graph.series.setTimeInterval(updateinterval);
                     setInterval(function () {
                         update_graph(succeeded_graph,
-                                     '/monitor/succeeded-tasks',
+                                     url_prefix() + '/monitor/succeeded-tasks',
                                      sts);
                         sts = current_unix_time();
                     }, updateinterval);
@@ -495,7 +504,7 @@ var flower = (function () {
 
             $.ajax({
                 type: 'GET',
-                url: '/monitor/failed-tasks',
+                url: url_prefix() + '/monitor/failed-tasks',
                 data: {lastquery: current_unix_time()},
                 success: function (data) {
                     failed_graph = create_graph(data, '-failed');
@@ -504,7 +513,7 @@ var flower = (function () {
                     failed_graph.series.setTimeInterval(updateinterval);
                     setInterval(function () {
                         update_graph(failed_graph,
-                                     '/monitor/failed-tasks',
+                                     url_prefix() + '/monitor/failed-tasks',
                                      fts);
                         fts = current_unix_time();
                     }, updateinterval);
